@@ -634,7 +634,7 @@ void DialogHelper::openWebBrowser( const OUString & sURL, const OUString &sTitle
         uno::Reference< XSystemShellExecute > xSystemShellExecute(
             m_xContext->getServiceManager()->createInstanceWithContext( OUSTR( "com.sun.star.system.SystemShellExecute" ), m_xContext), uno::UNO_QUERY_THROW);
         //throws css::lang::IllegalArgumentException, css::system::SystemShellExecuteException
-        xSystemShellExecute->execute( sURL, OUString(),  SystemShellExecuteFlags::DEFAULTS );
+        xSystemShellExecute->execute( sURL, OUString(),  SystemShellExecuteFlags::URIS_ONLY );
     }
     catch ( const uno::Exception& )
     {
@@ -1177,6 +1177,8 @@ void ExtMgrDialog::Resize()
     Size aUpdBtnSize( m_aUpdateBtn.GetSizePixel() );
     long offsetX;
 
+// last row of the box, lower 4 buttons
+
     Point aPos( RSC_SP_DLG_INNERBORDER_LEFT,
                 aTotalSize.Height() - RSC_SP_DLG_INNERBORDER_BOTTOM - aBtnSize.Height() );
 
@@ -1191,42 +1193,25 @@ void ExtMgrDialog::Resize()
     aPos.X() -= ( RSC_SP_CTRL_GROUP_X + aBtnSize.Width() );
     m_aAddBtn.SetPosPixel( aPos );
 
+// horizontal line above lower buttons
+
     Size aDivSize( aTotalSize.Width(), LINE_SIZE );
     aPos = Point( 0, aPos.Y() - LINE_SIZE - RSC_SP_DLG_INNERBORDER_BOTTOM );
     m_aDivider.SetPosSizePixel( aPos, aDivSize );
 
+// text "get more extensions"
+
     Size aFTSize( m_aGetExtensions.CalcMinimumSize() );
-    aPos = Point( RSC_SP_DLG_INNERBORDER_LEFT, aPos.Y() - RSC_CD_FIXEDTEXT_HEIGHT - 2*RSC_SP_DLG_INNERBORDER_BOTTOM );
+//    aPos = Point( RSC_SP_DLG_INNERBORDER_LEFT, aPos.Y() - RSC_CD_FIXEDTEXT_HEIGHT - 2*RSC_SP_DLG_INNERBORDER_BOTTOM );
+    aPos = Point( RSC_SP_DLG_INNERBORDER_LEFT, aPos.Y() - RSC_CD_PUSHBUTTON_HEIGHT - 2*RSC_SP_DLG_INNERBORDER_BOTTOM );
 
     m_aGetExtensions.SetPosSizePixel( aPos, aFTSize );
 
-    Size aCBSize(m_aBundledCbx.GetSizePixel());
-
-    offsetX = 0.5*(aTotalSize.Width() - RSC_SP_DLG_INNERBORDER_LEFT - RSC_SP_DLG_INNERBORDER_RIGHT - 3*(aCBSize.Width() + RSC_SP_CTRL_GROUP_X) );
-
-    aPos = Point(offsetX, aPos.Y() - RSC_CD_CHECKBOX_HEIGHT - 2*RSC_SP_DLG_INNERBORDER_BOTTOM);
-    m_aBundledCbx.SetPosSizePixel(aPos, aCBSize);
-    aPos.X() = aPos.X() + aCBSize.Width() + 2 * RSC_SP_CTRL_GROUP_X;
-    m_aSharedCbx.SetPosSizePixel(aPos, aCBSize);
-    aPos.X() = aPos.X() + aCBSize.Width() + 2 * RSC_SP_CTRL_GROUP_X;
-    m_aUserCbx.SetPosSizePixel(aPos, aCBSize);
-
-    Size aFTTypeOfExtSize(m_aTypeOfExtTxt.GetSizePixel());
-    aPos = Point(RSC_SP_DLG_INNERBORDER_LEFT , aPos.Y() - RSC_CD_FIXEDTEXT_HEIGHT - 2*RSC_SP_DLG_INNERBORDER_BOTTOM);
-
-    m_aTypeOfExtTxt.SetPosSizePixel(aPos, aFTTypeOfExtSize);
-
-    aPos.X() = RSC_SP_DLG_INNERBORDER_LEFT + aFTTypeOfExtSize.Width();
-    aPos.Y() = aPos.Y() + RSC_CD_FIXEDTEXT_HEIGHT;
-    aDivSize.Width() = aTotalSize.Width() - aFTTypeOfExtSize.Width() - RSC_SP_DLG_INNERBORDER_LEFT - RSC_SP_DLG_INNERBORDER_RIGHT;
-    m_aDivider2.SetPosSizePixel( aPos , aDivSize );
-
-
+// installation progress bar + cancel button , on the right of the text to get extensions
 
     aPos.X() = aTotalSize.Width() - RSC_SP_DLG_INNERBORDER_RIGHT - aBtnSize.Width();
     m_aCancelBtn.SetPosPixel( Point( aPos.X(), aPos.Y() - ((aBtnSize.Height()-aFTSize.Height())/2) ) );
 
-
     // Calc progress height
     long nProgressHeight = aFTSize.Height();
 
@@ -1257,9 +1242,47 @@ void ExtMgrDialog::Resize()
     aPos.X() = aRect1.Right() + RSC_SP_DLG_INNERBORDER_LEFT;
     m_aProgressText.SetPosSizePixel( aPos, aFTSize );
 
+// checkboxes + text "type of extensions"
+
+    long nWidth = m_aBundledCbx.GetCtrlTextWidth( m_aBundledCbx.GetText() );
+    Size aBCBSize(m_aBundledCbx.GetSizePixel());
+    aBCBSize.Width() = nWidth + 30;
+    m_aBundledCbx.SetSizePixel( aBCBSize );
+
+    nWidth = m_aSharedCbx.GetCtrlTextWidth( m_aSharedCbx.GetText() );
+    Size aSCBSize(m_aSharedCbx.GetSizePixel());
+    aSCBSize.Width() = nWidth + 30;
+    m_aSharedCbx.SetSizePixel( aSCBSize );
+
+    nWidth = m_aUserCbx.GetCtrlTextWidth( m_aUserCbx.GetText() );
+    Size aUCBSize(m_aUserCbx.GetSizePixel());
+    aUCBSize.Width() = nWidth + 30;
+    m_aUserCbx.SetSizePixel( aUCBSize );
+
+    offsetX = 0.5*(aTotalSize.Width() - RSC_SP_DLG_INNERBORDER_LEFT - RSC_SP_DLG_INNERBORDER_RIGHT - 3*RSC_SP_CTRL_GROUP_X - aBCBSize.Width() - aSCBSize.Width() - aUCBSize.Width() );
+
+    aPos = Point(offsetX, aPos.Y() - RSC_CD_CHECKBOX_HEIGHT - 2*RSC_SP_DLG_INNERBORDER_BOTTOM);
+    m_aBundledCbx.SetPosPixel( aPos );
+    aPos.X() += aBCBSize.Width() + 3 * RSC_SP_CTRL_GROUP_X;
+    m_aSharedCbx.SetPosPixel( aPos );
+    aPos.X() += aSCBSize.Width() + 3 * RSC_SP_CTRL_GROUP_X;
+    m_aUserCbx.SetPosPixel( aPos );
+
+    Size aFTTypeOfExtSize(m_aTypeOfExtTxt.GetSizePixel());
+    aPos = Point(RSC_SP_DLG_INNERBORDER_LEFT , aPos.Y() - RSC_CD_FIXEDTEXT_HEIGHT - 2*RSC_SP_DLG_INNERBORDER_BOTTOM);
+
+    m_aTypeOfExtTxt.SetPosSizePixel(aPos, aFTTypeOfExtSize);
+
+    aPos.X() = RSC_SP_DLG_INNERBORDER_LEFT + aFTTypeOfExtSize.Width();
+    aPos.Y() = aPos.Y() + RSC_CD_FIXEDTEXT_HEIGHT;
+    aDivSize.Width() = aTotalSize.Width() - aFTTypeOfExtSize.Width() - RSC_SP_DLG_INNERBORDER_LEFT - RSC_SP_DLG_INNERBORDER_RIGHT;
+    m_aDivider2.SetPosSizePixel( aPos , aDivSize );
+
+// extension listbox
+
     Size aSize( aTotalSize.Width() - RSC_SP_DLG_INNERBORDER_LEFT - RSC_SP_DLG_INNERBORDER_RIGHT,
-                aTotalSize.Height() - aBtnSize.Height() - LINE_SIZE - aFTSize.Height()
-                - aCBSize.Height() - aFTTypeOfExtSize.Height()
+                aTotalSize.Height() - aBtnSize.Height() - LINE_SIZE - aBtnSize.Height()
+                - aBCBSize.Height() - aFTTypeOfExtSize.Height()
                 - RSC_SP_DLG_INNERBORDER_TOP - 5*RSC_SP_DLG_INNERBORDER_BOTTOM );
 
     m_pExtensionBox->SetSizePixel(aSize );
