@@ -217,12 +217,6 @@ SfxOrganizeDlg_Impl::SfxOrganizeDlg_Impl( SfxTemplateOrganizeDlg* pParent,
     pFileDlg    ( NULL )
 
 {
-    // Enable sorting in the listboxes
-    aLeftLb.GetModel()->SetSortMode( SortAscending );
-    aRightLb.GetModel()->SetSortMode( SortAscending );
-    aLeftLb.GetModel()->SetCompareHdl( LINK( &aLeftLb, SvTreeListBox, DefaultCompare ) );
-    aRightLb.GetModel()->SetCompareHdl( LINK( &aRightLb, SvTreeListBox, DefaultCompare ) );
-
     // update the SfxDocumentTemplates the manager works with
     if ( aMgr.GetTemplates() )  // should never fail, but who knows ....
     {
@@ -232,8 +226,6 @@ SfxOrganizeDlg_Impl::SfxOrganizeDlg_Impl( SfxTemplateOrganizeDlg* pParent,
             pWaitObjectRange = pDialog;
 
         WaitObject aWaitCursor( pWaitObjectRange );
-        const_cast< SfxDocumentTemplates* >( aMgr.GetTemplates() )->EnableRegionSorting();
-        const_cast< SfxDocumentTemplates* >( aMgr.GetTemplates() )->EnableTemplateSorting();
         const_cast< SfxDocumentTemplates* >( aMgr.GetTemplates() )->Update( sal_True /* be smart */ );
             // this const_cast is a hack - but the alternative would be to
             // * have a method which returns the templates non-const
