@@ -698,7 +698,9 @@ void RtfExport::PrepareNewPageDesc( const SfxItemSet* pSet,
     else if ( pNewPgDesc )
         m_pSections->AppendSection( pNewPgDesc, rNd, pFmt, nLnNm );
 
-    AttrOutput().SectionBreak( msword::PageBreak, m_pSections->CurrentSectionInfo() );
+    // Don't insert a page break, when we're changing page style just because the next page has to be a different one.
+    if (!m_pAttrOutput->m_pPrevPageDesc || m_pAttrOutput->m_pPrevPageDesc->GetFollow() != pNewPgDesc)
+        AttrOutput().SectionBreak( msword::PageBreak, m_pSections->CurrentSectionInfo() );
 }
 
 bool RtfExport::DisallowInheritingOutlineNumbering( const SwFmt& rFmt )
@@ -914,7 +916,15 @@ OString RtfExport::OutChar(sal_Unicode c, int *pUCMode, rtl_TextEncoding eDestEn
     }
     if (pStr) {
         aBuf.append(pStr);
-        aBuf.append(' ');
+        switch (c)
+        {
+            case 0xa0:
+            case 0x1e:
+            case 0x1f:
+                break;
+            default:
+                aBuf.append(' ');
+        }
     }
     return aBuf.makeStringAndClear();
 }
@@ -1185,6 +1195,7 @@ void RtfExport::OutPageDescription( const SwPageDesc& rPgDsc, sal_Bool bWriteRes
     // title page
     if( pAktPageDesc != &rPgDsc )
     {
+        Strm() << OOO_STRING_SVTOOLS_RTF_TITLEPG;
         pAktPageDesc = &rPgDsc;
         if( pAktPageDesc->GetMaster().GetAttrSet().GetItemState( RES_HEADER,
                     sal_False, &pItem ) == SFX_ITEM_SET )
