@@ -83,11 +83,17 @@ namespace
 
     void SwBreakDashedLine::MouseMove( const MouseEvent& rMEvt )
     {
-        Point aEventPos( GetPosPixel() + rMEvt.GetPosPixel() );
-        if ( !m_pWin->Contains( aEventPos ) )
-            m_pWin->Fade( false );
+        if ( rMEvt.IsLeaveWindow() )
+        {
+            // don't fade if we just move to the 'button'
+            Point aEventPos( GetPosPixel() + rMEvt.GetPosPixel() );
+            if ( !m_pWin->Contains( aEventPos ) )
+                m_pWin->Fade( false );
+        }
         else if ( !m_pWin->IsVisible() )
+        {
             m_pWin->Fade( true );
+        }
 
         if ( !rMEvt.IsSynthetic() )
         {
@@ -176,30 +182,26 @@ void SwPageBreakWin::Paint( const Rectangle& )
     aSeq[2] = Primitive2DReference( new DiscreteBitmapPrimitive2D(
             aImg.GetBitmapEx(), B2DPoint( nImgOfstX, 1.0 ) ) );
 
-    // Paint the symbol if not readonly button
-    if ( IsEnabled() )
-    {
-        double nTop = double( aRect.getHeight() ) / 2.0;
-        double nBottom = nTop + 4.0;
-        double nLeft = aRect.getWidth( ) - ARROW_WIDTH - 6.0;
-        if ( bRtl )
-            nLeft = ARROW_WIDTH - 2.0;
-        double nRight = nLeft + 8.0;
+    double nTop = double( aRect.getHeight() ) / 2.0;
+    double nBottom = nTop + 4.0;
+    double nLeft = aRect.getWidth( ) - ARROW_WIDTH - 6.0;
+    if ( bRtl )
+        nLeft = ARROW_WIDTH - 2.0;
+    double nRight = nLeft + 8.0;
 
-        B2DPolygon aTriangle;
-        aTriangle.append( B2DPoint( nLeft, nTop ) );
-        aTriangle.append( B2DPoint( nRight, nTop ) );
-        aTriangle.append( B2DPoint( ( nLeft + nRight ) / 2.0, nBottom ) );
-        aTriangle.setClosed( true );
+    B2DPolygon aTriangle;
+    aTriangle.append( B2DPoint( nLeft, nTop ) );
+    aTriangle.append( B2DPoint( nRight, nTop ) );
+    aTriangle.append( B2DPoint( ( nLeft + nRight ) / 2.0, nBottom ) );
+    aTriangle.setClosed( true );
 
-        BColor aTriangleColor = Color( COL_BLACK ).getBColor( );
-        if ( Application::GetSettings().GetStyleSettings().GetHighContrastMode() )
-            aTriangleColor = Color( COL_WHITE ).getBColor( );
+    BColor aTriangleColor = Color( COL_BLACK ).getBColor( );
+    if ( Application::GetSettings().GetStyleSettings().GetHighContrastMode() )
+        aTriangleColor = Color( COL_WHITE ).getBColor( );
 
-        aSeq.realloc( aSeq.getLength() + 1 );
-        aSeq[ aSeq.getLength() - 1 ] = Primitive2DReference( new PolyPolygonColorPrimitive2D(
-                   B2DPolyPolygon( aTriangle ), aTriangleColor ) );
-    }
+    aSeq.realloc( aSeq.getLength() + 1 );
+    aSeq[ aSeq.getLength() - 1 ] = Primitive2DReference( new PolyPolygonColorPrimitive2D(
+               B2DPolyPolygon( aTriangle ), aTriangleColor ) );
 
     Primitive2DSequence aGhostedSeq( 1 );
     double nFadeRate = double( m_nFadeRate ) / 100.0;
@@ -213,6 +215,7 @@ void SwPageBreakWin::Paint( const Rectangle& )
                     *this, aNewViewInfos );
 
     pProcessor->process( aGhostedSeq );
+    delete pProcessor;
 }
 
 void SwPageBreakWin::Select( )
@@ -303,9 +306,13 @@ void SwPageBreakWin::Select( )
 
 void SwPageBreakWin::MouseMove( const MouseEvent& rMEvt )
 {
-    Point aEventPos( rMEvt.GetPosPixel() + rMEvt.GetPosPixel() );
-    if ( !Contains( aEventPos ) && !PopupMenu::IsInExecute() )
-        Fade( false );
+    if ( rMEvt.IsLeaveWindow() )
+    {
+        // don't fade if we just move to the 'line', or the popup menu is open
+        Point aEventPos( rMEvt.GetPosPixel() + rMEvt.GetPosPixel() );
+        if ( !Contains( aEventPos ) && !PopupMenu::IsInExecute() )
+            Fade( false );
+    }
     else if ( !IsVisible() )
         Fade( true );
 }
@@ -327,9 +334,13 @@ void SwPageBreakWin::UpdatePosition( const Point* pEvtPt )
     }
 
     const SwPageFrm* pPageFrm = GetPageFrame();
-    const SwFrm* pPrevPage = pPageFrm->GetPrev();
-    while ( pPrevPage && ( pPrevPage->Frm().Top( ) == pPageFrm->Frm().Top( ) ) )
+    const SwFrm* pPrevPage = pPageFrm;
+    do
+    {
         pPrevPage = pPrevPage->GetPrev();
+    }
+    while ( pPrevPage && ( ( pPrevPage->Frm().Top( ) == pPageFrm->Frm().Top( ) )
+                || static_cast< const SwPageFrm* >( pPrevPage )->IsEmptyPage( ) ) );
 
     Rectangle aBoundRect = GetEditWin()->LogicToPixel( pPageFrm->GetBoundRect().SVRect() );
     Rectangle aFrmRect = GetEditWin()->LogicToPixel( pPageFrm->Frm().SVRect() );
@@ -409,7 +420,7 @@ const SwPageFrm* SwPageBreakWin::GetPageFrame( )
 
 void SwPageBreakWin::SetReadonly( bool bReadonly )
 {
-    Enable( !bReadonly );
+    ShowAll( !bReadonly );
 }
 
 void SwPageBreakWin::Fade( bool bFadeIn )
