@@ -261,6 +261,7 @@ bool nsscrypto_initialize( const css::uno::Reference< css::lang::XMultiServiceFa
 
     PR_Init( PR_USER_THREAD, PR_PRIORITY_NORMAL, 1 ) ;
 
+    bool bSuccess = true;
     // there might be no profile
     if ( sCertDir.getLength() > 0 )
     {
@@ -272,10 +273,11 @@ bool nsscrypto_initialize( const css::uno::Reference< css::lang::XMultiServiceFa
             PR_GetErrorText(error);
             if (error)
                 xmlsec_trace("%s",error);
-            return false ;
+            bSuccess = false;
         }
     }
-    else
+
+    if( sCertDir.isEmpty() || !bSuccess )
     {
         xmlsec_trace("Initializing NSS without profile.");
         if ( NSS_NoDB_Init(NULL) != SECSuccess )
@@ -298,7 +300,7 @@ bool nsscrypto_initialize( const css::uno::Reference< css::lang::XMultiServiceFa
         deleteRootsModule();
 
 #if defined SYSTEM_MOZILLA
-        OUString rootModule(RTL_CONSTASCII_USTRINGPARAM("libnssckbi"SAL_DLLEXTENSION));
+        OUString rootModule(RTL_CONSTASCII_USTRINGPARAM("libnssckbi" SAL_DLLEXTENSION));
 #else
         OUString rootModule(RTL_CONSTASCII_USTRINGPARAM("${LO_LIB_DIR}/libnssckbi" SAL_DLLEXTENSION));
 #endif
